@@ -104,12 +104,12 @@ root_check()
 
 check_os_and_patch_level()
 {
-   uname -r | grep 5.[6-8] > /dev/null
+   uname -r | grep 5.[6-9] > /dev/null
    RETVAL=$?
 
    if [ $RETVAL -gt 0 ]
    then
-     echo "This updated Solaris daemon is designed for Solaris 6, 7 and 8 only. Terminating script"
+     echo "This updated Solaris daemon is designed for Solaris 6, 7, 8 and 9 only. Terminating script"
      exit 8
    fi 
 	
@@ -155,6 +155,14 @@ check_os_and_patch_level()
    then
 	echo "No additional patches are required for Solaris 8. Continuing."
    fi
+
+   uname -r | grep 5.9 > /dev/null
+   RETVAL=$?
+
+   if [ $RETVAL -lt 1 ]
+   then
+	echo "No additional patches are required for Solaris 9. Continuing."
+   fi
 }
 
 ########################################################################
@@ -240,7 +248,7 @@ backup_key_files()
 ########################################################################
 
 echo
-echo "Note: This script is for Solaris 6, 7 and 8 installations only"
+echo "Note: This script is for Solaris versions between 6 and 9 only"
 echo "      Snare has not been tested on other systems."
 echo
 
